# OSMViz

[![Build Status](https://travis-ci.org/hugovk/osmviz.svg?branch=master)](https://travis-ci.org/hugovk/osmviz)
[![codecov](https://codecov.io/gh/hugovk/osmviz/branch/master/graph/badge.svg)](https://codecov.io/gh/hugovk/osmviz)

An OpenStreetMap Visualization Toolkit for Python

## OSMViz License

OSMViz is released under the MIT license.
See LICENSE in this directory.


# OpenStreetMap License

Tiles taken from the openstreetmap.org server
have a usage policy as outlined here:

http://wiki.openstreetmap.org/wiki/Tile_usage_policy

These tiles are (c) OpenStreetMap & contributors, CC-BY-SA.
OpenStreetMap: http://www.openstreetmap.org
CC-BY-SA: http://creativecommons.org/licenses/by-sa/2.0/

You can tell OSMViz to use any slippymap server provided
tiles that you wish, which may have its own usage policy.

## About

OSMViz is a small set of Python tools for retrieving
and using Mapnik tiles from a Slippy Map server
(you may know these as OpenStreetMap images).

## Requirements

* Python 2.7 or Python 3.3+
* Pygame and/or Pillow

## Installation

Either:

    pip install osmviz

Or just add the src directory to your PYTHONPATH.

## Help

See [html/doc.html](https://hugovk.github.io/osmviz/html/doc.html)
